stalker.core.models.Status
==========================

.. inheritance-diagram::
     stalker.core.models.Status
     :parts: 1

.. currentmodule:: stalker.core.models

.. autoclass:: Status
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Status.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Status.code
      ~Status.created_by
      ~Status.date_created
      ~Status.date_updated
      ~Status.description
      ~Status.name
      ~Status.nice_name
      ~Status.notes
      ~Status.tags
      ~Status.type
      ~Status.updated_by
   
   